@@ -66,9 +66,6 @@ class MachineLearningMixin:
         if type:
             ml_workflow["type"] = type
 
-        # Inject token
-        ml_workflow["squirro_token"] = self.refresh_token
-
         # Inject ml_models
         self._inject_ml_models(ml_workflow, ml_models)
 
